Crate luminance_glfw

Crate luminance_glfw 

GLFW backend for luminance.

Structs

GL33Context
Luminance OpenGL 3.3 context.
GlfwSurface
GLFW surface.

Enums

GlfwSurfaceError
Error that can be risen while creating a surface.
StateQueryError
An error that might happen when the context is queried.